@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 #  mainframe.tcl
 #  This file is part of Unifix BWidget Toolkit
-#  $Id: mainframe.tcl,v 1.24.2.1 2010/11/09 16:05:43 oehhar Exp $
+#  $Id: mainframe.tcl,v 1.24.2.3 2011/05/25 15:10:07 oehhar Exp $
 # ------------------------------------------------------------------------------
 #  Index of commands:
 #     - MainFrame::create
@@ -49,6 +49,7 @@ namespace eval MainFrame {
 	{-menubarfont   String     ""  0}
 	{-menuentryfont String     ""  0}
 	{-statusbarfont String     ""  0}
+	{-sizegrip      Boolean    0   1}
     }
 
     Widget::addmap MainFrame "" .frame  {-width {} -height {} -background {}}
@@ -166,6 +167,9 @@ proc MainFrame::create { path args } {
                       -height      [expr {[winfo reqheight $label]-2}] \
                       -borderwidth 1 \
                       -relief      sunken]
+    if {[Widget::theme] && [Widget::getoption $path -sizegrip]} {
+	pack [ttk::sizegrip $botframe.sg] -side right -anchor se
+    }
     pack $status    -in $botframe -fill x -pady 2
     pack $botframe  -side bottom -fill x
     pack $userframe -fill both -expand yes
@@ -303,11 +307,11 @@ proc MainFrame::addtoolbar { path } {
     set index     $_widget($path,ntoolbar)
     set toolframe $path.topf.f$index
     set toolbar   $path.topf.tb$index
-    set bg        [Widget::getoption $path -background]
     if { $tcl_platform(platform) == "unix" } {
 	if {[Widget::theme]} {
 	    ttk::frame $toolframe -padding 1
 	} else {
+	    set bg [Widget::getoption $path -background]
 	    frame $toolframe -relief raised -borderwidth 1 \
 		-takefocus 0 -highlightthickness 0 -background $bg
 	}
@@ -316,6 +320,7 @@ proc MainFrame::addtoolbar { path } {
 	    ttk::frame $toolframe
 	    set sep [ttk::separator $toolframe.sep -orient horizontal]
 	} else {
+	    set bg [Widget::getoption $path -background]
 	    frame $toolframe -relief flat -borderwidth 0 -takefocus 0 \
 		-highlightthickness 0 -background $bg
 	    set sep [Separator::create $toolframe.sep -orient horizontal -background $bg]
